NAME = "hubblescope"

ICON = "🔭"

DESCRIPTION = f"{ICON} tools to access and process Hubble Space Telescope imagery and other datasets on AWS Open Data Registry."

VERSION = "4.42.1"

MARQUEE = "https://github.com/kamangir/hubble/raw/main/assets/hst/u4ge0106r_c0m.gif"
